"""
To be able to generate obs_seq.in files, we need a dictionary to convert obs kinds to numbers

  a) we read the obs kind definitions (obs_kind_mod.f90 from DART code) 
  b) we generate a python file with this dictionary

# Note: to include it in the documentary, the file needs to exist also in the repository 
# (so the documentation generator SPHINX can read it)
"""
import os, sys
import shutil


def _dict_to_py(d, outfile):
    """Write a python dictionary to a .py file

    Args:
        d (dict): dictionary to write
        outfile (str): path to output file

    Returns:
        None
    """
    with open(outfile, 'w') as f:
        txt = '""" NOTE: This file is autogenerated! \nUse dartwrf/create_obskind_table.py to regenerate!\n"""\nobs_kind_nrs = {\n'
        for k, v in d.items():
            txt += '"'+k+'": '+str(v)+', \n'
        txt += '}'
        f.write(txt)


def _save_config_to_scriptsdir(server_config, original_scripts_dir):
    try:
        dir_path = os.path.dirname(os.path.realpath(__file__))
        shutil.copyfile(dir_path+'/../config/'+server_config,
                        original_scripts_dir+'/server_config.py')
    except shutil.SameFileError:
        pass


def run(server_config='jet.py'):
    """Create obskind.py from obs_kind_mod.f90
    """

    # usually /home/DART-WRF/dartwrf/
    original_scripts_dir = '/'.join(__file__.split('/')[:-1])

    # copy the original config to "scripts_dir"
    _save_config_to_scriptsdir(server_config, original_scripts_dir)

    # import the config from scripts_dir
    sys.path.append(original_scripts_dir)
    from server_config import cluster
    from dartwrf import obs

    obskind_dictionary = obs.obskind_read(cluster.dart_srcdir)

    _dict_to_py(obskind_dictionary, original_scripts_dir+'/obs/obskind.py')
    print('>>>', original_scripts_dir+'/obs/obskind.py', 'created')


if __name__ == '__main__':
    run(server_config='jet_ACF.py')
